% computeProbablilities : evaluates oagsm and gsm densities 
%
% [p_ori,p_nor]=computeProbabilities(x,Cnor,Cori,Cn,logz_list)
%
% Inputs :
% x - vectorized input patches
% Cnor - non-oriented covaraince
% Cori - Ntheta x 1 cell array of oriented covariances
% Cn - noise covariance
% logz_list - Nz x 1 list of log(z) values
%
% Ouputs :
% p_ori - oriented (oagsm) probabilities
% p_nor - non-oriented (gsm) probabilities
%
% note : the produced probabilities are extremely small, I have concerns
% about numerical underflow ...

function [p_ori,p_nor]=computeProbabilities(x,Cnor,Cori,Cn,logz_list)
  Nz=length(logz_list);
  Ntheta=length(Cori);
  Npatches=size(x,2);
  p_nor=zeros(1,Npatches);
  p_ori=zeros(1,Npatches);

  d=size(x,1);
  % compute gsm probability
  % simultaneously diagonalize Cnor and Cn
  [T D]=simuDiag(Cn,Cnor);
  xp=inv(T)*x;
  
  for kz=1:Nz
    z=exp(logz_list(kz));
    dzi=sparse(inv(eye(d)+z*D));
    qf=sum((dzi*xp).*xp);
    p_nor=p_nor+1/((2*pi)^(d/2)*sqrt(det(z*Cnor+Cn)))*exp(-.5*qf);
  end

  for ktheta=1:Ntheta 
    [T D]=simuDiag(Cn,Cori{ktheta});
    xp=inv(T)*x;
    
    for kz=1:Nz
      z=exp(logz_list(kz));
      dzi=sparse(inv(eye(d)+z*D));
      qf=sum((dzi*xp).*xp);
      p_ori=p_ori+1/((2*pi)^(d/2)*sqrt(det(z*Cori{ktheta}+Cn)))*exp(-.5*qf);
    end
  end
  
  p_nor=p_nor/Nz;
  p_ori=p_ori/(Nz*Ntheta);
  