% emIterBeta : perform EM iteration to calculate beta
%
% [beta,betasave]=emIterBeta(pori,pnor,beta0,Niter)
%
% Inputs :
% pori - Npatch x 1 array of oriented (oagsm) probabilites
% pnor - Npatch x 1 array of non-oriented (gsm) probabilites
% beta0 - initial value of beta (usually 0.5)
% Niter - number of iterations
%
% Outputs :
% beta - final iterate of beta
% betasave - Niter x 1 array of all iterates

function [beta,betasave]=emIterBeta(pori,pnor,beta0,Niter)
  beta=beta0;
  for k=1:Niter
    % E step
    t = (beta*pori)./(beta*pori +(1-beta)*pnor);
    % M step
    beta = mean(t);
    % record data
    betasave(k)=beta;
  end
  