% fullPyrBand : returns pyramid band in fullband form
%
% b = fullPyrBand(pyr,pind,K,level)
%
% fullPyrBand returns a pyramid band in fullband data structure form.
% If K includes parent, then b will include the parent bands. This
% makes it more convenient for extracting patches including parent 
% coefficients. 
%
% Inputs: 
% "pyr","pind" - pyramid coefficient and pyramid index structures as 
%  used in pyrTools
% "K" - generalized neighborhood descriptor
% "level" - desired level of the child band. If level 0 is
% given then the scalar highpass band will be returned
%
% Outputs:
% "b" - pyramid band of specified level in fullband data structure form:
% b.child -  M x N x nbands array of child coefficients
% b.parent - M x N x nbands arrat of parent coefficients, upsampled in
% Fourier domain to have the same size as child coefficients.
%
% See also getBandFromFullBand

function b = fullPyrBand(pyr,pind,K,level)
% return highpass if requested (if k is 0)
if level==0
  b.child = pyrBand(pyr,pind,1);
  return
end

nbands = K.nbands;
%if nbands ~= (sum(pind(1,1)==pind(:,1))-1)
%  error('K.nbands and pind size are inconsistent');
%end

bdim = pind((level-1)*nbands+2,:);
b.child = zeros(bdim(1),bdim(2),nbands);
for band = 1:nbands
  b.child(:,:,band) = pyrBand(pyr,pind,1 + (level-1)*nbands + band);
end

if K.useparent
  b.parent = zeros(bdim(1),bdim(2),nbands);
  for band = 1:nbands
    tband = pyrBand(pyr,pind,1+level*nbands+band);
    b.parent(:,:,band)=upsampleFourier(tband,bdim);
  end
end
