% calcPSNR : Compute peak-to-peak signal to noise ratio
%
% r = psnr(imo,imc)
%
% Inputs:
% imo - original image
% imc - noisy image
% If imc is a cell array, then SNR gets calculated for each element of imc
%
% Outputs:
% PSNR - output PSNR
% See also calcSNR
function PSNR=calcPSNR(imo,imc)

if (iscell(imc))
  PSNR=zeros(size(imc));
  for k=1:numel(imc)
    r(k)=calcPSNR(imo,imc{k});
  end
else
  mse=sum( (imo(:)-imc(:)).^2 )/numel(imo);
  PSNR=10*log10(255^2/mse);
end
