% calcSNR : compute signal to noise ratio
%
% SNR = calcSNR(imo,imc)
%
% Calculate signal to noise ratio
%
% Inputs:
% imo - original signal
% imc - noisy signal
% If imc is a cell array, then SNR gets calculated for each element of imc
%
% Outputs:
% SNR - signal to noise ratio (in dB)
%
% See also calcPSNR
function SNR=calcSNR(imo,imc)

if (iscell(imc))
  SNR=zeros(size(imc));
  for k = 1:numel(imc)
    SNR(k)=calcSNR(imo,imc{k});
  end
else
  if isempty(imc)
    SNR=NaN;
  else
    difference=imc-imo;
    diffmean = mean2(difference);
    imomean = mean2(imo);
    vdiff = sum(sum( abs(difference-diffmean).^2))/...
            (prod(size(difference))- 1);
    vimo = sum(sum(abs(imo-imomean).^2))/...
           (prod(size(imo))-1);
    
    %v = var2(difference,mean);
    SNR=10*log10(vimo/vdiff);
  end
end
